/**
* This sample shows how to use an analog input sequence acquisition using software and/or hardware trigger
* In this sample we do not use DMA but you can also change it to use DMA
**/
#include "stdafx.h"

/**
* Pointer that will be allocated and that will enables to read the data of the board
**/
USHORT * data = NULL;
DWORD	dataSize = 0;

/**
* Interrupt routine that enables to get the data read by the board
**/
static void SequenceInterruptRoutine (HANDLE	deviceHandle,
							   BYTE		fifoOverflow,
							   DWORD	interruptSource,
							   DWORD	interruptMask,
							   PWORD	args,
							   DWORD	argsCount )
{
	UNREFERENCED_PARAMETER(args);
	/* switch through the possible interrupt sources */

	/* check the interrupt fifo overflow */
	if ( fifoOverflow )
	{
		printf("Error: interrupt fifo overflow. That means that your software do not handle the interrupts fast enough.\n");
	}

	/* DMA */
	if ( interruptSource & 0x4 )
	{
		if ( interruptMask & 0x4 )
		{
			printf("internal sequence fifo overflow \n");
		}
		else
		{
			LONG read = 0;
			/* get the sequence data */
			read = l_PCI3116_ReadSequenceData( deviceHandle, dataSize, data );
			if ( read < 0 )
			{
				printf("error %d in l_PCI3116_ReadSequenceData \n", (int) read);
			}
			else
			{
				DWORD i = 0;
				/* display the values */
				for( i = 0 ; i < argsCount ; i++ )
				{
					/* each 4 values, go to the line */
					if ( i % 4 == 0 )
					{
						printf("\n");
					}
					printf("0x%.4x ", data[i] );
				}
				printf("\n");
			}
		}
	}

	/* DMA counter overflow */
	if ( interruptSource & 0x8 )
	{
		printf("Error: DMA counter overflow. This stop the acquisition. Can be used to detect that an acquisition is over. \n");
	}

	/* PLD Fifo overflow */
	if ( interruptSource & 0x10 )
	{
		printf("Error: PLD Fifo overflow. This stop the acquisition.\n");
	}
}

/* entry point */
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE boardHandle = NULL;
	ULONG readValue = 0;
	ULONG sequenceNbr = 0;
	BYTE channels[16] = {0};
	BYTE polarity[16] = {0};
	BYTE gain[16] = {0};
	BYTE inputMode = 0;
	BYTE hardwareTrigger = 0;
	BYTE softwareTrigger = 0;
	DWORD sequenceBeforeInterrupt = 0;
	DWORD sequenceTriggerCount = 0;

	/* initialize the acquisition */
	channels[0] = 0;
	channels[1] = 1;
	channels[2] = 2;
	channels[3] = 3;

	polarity[0] = PCI3116_OUTPUT_MODE_BIPOLAR;
	polarity[1] = PCI3116_OUTPUT_MODE_BIPOLAR;
	polarity[2] = PCI3116_OUTPUT_MODE_BIPOLAR;
	polarity[3] = PCI3116_OUTPUT_MODE_BIPOLAR;

	gain[0] = PCI3116_GAIN_1;
	gain[1] = PCI3116_GAIN_1;
	gain[2] = PCI3116_GAIN_1;
	gain[3] = PCI3116_GAIN_1;

	/* open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d opening the board \n", returnValue);
		_getch();
		return -1;
	}

	/* display some useful informations */
	printf("\n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n");
	printf("* This sample will initialize a triggered acquisition\n");
	printf("* The sequence is : \n");
	printf("*   - Channel 0, bipolar, gain 1 \n");
	printf("*   - Channel 1, bipolar, gain 1 \n");
	printf("*   - Channel 2, bipolar, gain 1 \n");
	printf("*   - Channel 3, bipolar, gain 1 \n");
	printf("* Converting time is set to 100us \n");
	printf("* Delay time is set to 500ms \n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n\n");

	/* ask the input mode */
	ReadUlong("Select the input mode (0: Single-ended, 1: Differential) ", 0, 1, &readValue);
	switch ( readValue )
	{
		case 0:
			inputMode = PCI3116_INPUT_MODE_SINGLE_ENDED;
			break;
		case 1:
			inputMode = PCI3116_INPUT_MODE_DIFFERENTIAL;
			break;
	}

	/* set the selected input mode */
	returnValue = i_PCI3116_SetAnalogInputMode( boardHandle, inputMode );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_SetAnalogInputMode \n", returnValue);
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* set the board interrupt routine */
	returnValue = i_PCI3116_SetBoardIntRoutine( boardHandle, SequenceInterruptRoutine );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_SetBoardIntRoutine \n", returnValue);
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* ask the sequence count */
	ReadUlong("How many sequences do you want to acquire? (0: Continuous) If you choose a value superior to 0, after this number of sequence is acquire the board will stop to generate data. "
		, 0, 0xFFFFFFFF, &readValue);
	switch ( readValue )
	{
		case 0:
			sequenceNbr = PCI3116_CONTINUOUS_CYCLE;
			break;
		default:
			sequenceNbr = readValue;
			break;
	}

	/* ask the number of sequences before interrupt */
	ReadUlong("How many sequences do you want before the board generate an interrupt ? ", 1, 0xFFFFFFFF, &sequenceBeforeInterrupt );

	/* allocate memory */
	dataSize = sequenceBeforeInterrupt * 4 * sizeof(USHORT);
	data = (USHORT*)malloc( dataSize );
	if ( data == NULL )
	{
		printf("Error in malloc. data is null \n" );
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* ask the software trigger type */
	ReadUlong("Do you want to enable software trigger? (0: No, 1: Yes) ", 0, 1, &readValue);
	if ( readValue == 1 )
	{		
		ReadUlong("Select the trigger type? (0: One shot, 1: Sequence trigger, 2: Single sequence) ", 0, 2, &readValue);
		switch ( readValue )
		{
			case 0:
				softwareTrigger = PCI3116_SOFT_TRIGGER_ENABLED | PCI3116_TRIGGER_ONE_SHOT;
				break;
			case 1:
				/* for sequence trigger, we have to know the number of sequence to acquire during one trigger */
				softwareTrigger = PCI3116_SOFT_TRIGGER_ENABLED | PCI3116_TRIGGER_SEQUENCE_TRIGGER;	
				ReadUlong("Select the number of sequences that must be acquired per trigger? ", 1, 0xFFFFFFFF, &sequenceTriggerCount);
				break;
			case 2:
				softwareTrigger = PCI3116_SOFT_TRIGGER_ENABLED | PCI3116_TRIGGER_SINGLE_SEQUENCE;
				break;
		}
	}
	else
	{
		softwareTrigger = PCI3116_SOFT_TRIGGER_DISABLED;
	}
	
	/* ask for hardware trigger */
	ReadUlong("Do you want to use hardware trigger? (0: No, 1: Yes) ", 0, 1, &readValue);
	if ( readValue == 1)
	{
		BYTE triggerEdge = 0;
		BYTE triggerType = 0;

		/* detection edge */
		ReadUlong("What front do you want to use? (0: Low, 1: High, 2: Both) ", 0, 2, &readValue);
		switch ( readValue )
		{
			case 0:
				triggerEdge = PCI3116_EXT_TRIGGER_ENABLED_LOW;
				break;
			case 1:
				triggerEdge = PCI3116_EXT_TRIGGER_ENABLED_HIGH;
				break;
			case 2:
				triggerEdge = PCI3116_EXT_TRIGGER_ENABLED_BOTH;
				break;
		}

		/* trigger type */
		ReadUlong("What trigger type do you want to use? (0: One shot, 1: Sequence trigger, 2: Single sequence) ", 0, 2, &readValue);
		switch ( readValue )
		{
			case 0:
				triggerType = PCI3116_TRIGGER_ONE_SHOT;
				break;
			case 1:
				triggerType = PCI3116_TRIGGER_SEQUENCE_TRIGGER;	
				ReadUlong("Select the number of sequences that must be acquired per trigger? ", 1, 0xFFFFFFFF, &sequenceTriggerCount);
				break;
			case 2:
				triggerType = PCI3116_TRIGGER_SINGLE_SEQUENCE;
				break;
		}

		/* compute the hardware trigger parameter */
		hardwareTrigger = triggerEdge | triggerType;
	}
	else
	{
		hardwareTrigger = PCI3116_EXT_TRIGGER_DISABLED;
	}

	/* init and start an analog input sequence without DMA */
	returnValue = i_PCI3116_InitAndStartAnalogInputSequence (boardHandle,
		sequenceNbr,				/* 0: continuous, else, the number of sequence to acquire before stopping */
		sequenceBeforeInterrupt,	/* number of sequence in one interruption */
		4,							/* Number of channels in the sequence */
		channels,
		gain,
		polarity,				
		100,						/* 100us converting time */
		500000,						/* 500ms delay time */
		softwareTrigger,
		hardwareTrigger,
		sequenceTriggerCount );
	if ( returnValue != 0 )
	{
		printf("Error %d in i_PCI3116_StartAnalogInputSequence \n", returnValue);
		i_PCI3116_ResetBoardIntRoutine( boardHandle );
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* display some help */
	printf("Press space to trigger the acquisition via software, and 'ESC' to exit the acquisition. \n");

	for(;;)
	{
		if ( _kbhit() )
		{
			int hitChar = _getch();
			/* space */
			if ( hitChar == 32 )
			{
				/* trigger the acquisition */
				printf("Trigger acquisition \n");
				returnValue = i_PCI3116_TriggerAnalogAcquisition( boardHandle );
				if ( returnValue != 0 )
				{
					printf("Error %d in i_PCI3116_TriggerAnalogAcquisition \n", returnValue);
					i_PCI3116_StopAnalogAcquisition( boardHandle );
					i_PCI3116_ResetBoardIntRoutine( boardHandle );
					i_PCI3116_CloseBoard(boardHandle);
					_getch();
					return -1;
				}
			}
			/* esc */
			else if ( hitChar == 27 )
			{
				/* exit the loop */
				break;
			}
		}
		Sleep(100);
		DisplayRunningStatus();
	}

	/* stop the acquisition */
	returnValue = i_PCI3116_StopAnalogAcquisition( boardHandle );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_StopAnalogAcquisition \n", returnValue);
	}
	else
	{
		printf("i_PCI3116_StopAnalogAcquisition OK \n");
	}

	/* reset the interrupt routine */
	returnValue = i_PCI3116_ResetBoardIntRoutine( boardHandle );
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_ResetBoardIntRoutine \n", returnValue);
	}
	else
	{
		printf("i_PCI3116_ResetBoardIntRoutine OK \n");
	}

	/* close the board */
	returnValue = i_PCI3116_CloseBoard(boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_CloseBoard \n", returnValue);
	}
	else
	{
		printf("i_PCI3116_CloseBoard OK \n");
	}

	/* free memory */
	free(data);

	/* end */
	printf("\n Press any key to exit the sample ...");
	_getch();

	return 0;
}

