/**
* This sample shows how to calibrate the analog outputs
**/
#include "stdafx.h"

/**
* Do the offset calibration around 0 V
**/
INT doOffsetCalibration(HANDLE boardHandle, DWORD * gain, DWORD * offset)
{
	INT returnValue = 0;

	/* write the analog output value as 0 V */
	returnValue = i_PCI3116_Write1AnalogOutput(boardHandle, 0, 1, 2048);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_Write1AnalogOutput\n", returnValue);
		return -1;
	}
	else
	{
		printf("i_PCI3116_Write1AnalogOutput OK \n");
	}
	
	printf("\nPlease measure the analog output 0 voltage (between pins 30 and 12).\n");
	printf("Press the + and - keys to set 0,00V, then press enter.\n");

	while(1)
	{
		printf("\rGain: %4d\tOffset: %4d", *gain, *offset);
		switch( _getch() )
		{
			case '+':
				{
					if ( (*offset + 1) <= 255 )
					{
						*offset = *offset + 1;
						returnValue = i_PCI3116_WritePotis(boardHandle, 5, *offset);
						if (returnValue != 0)
						{
							printf("Error %d in i_PCI3116_WritePotis\n", returnValue);
							return -1;
						}
					}
				}
				break;
			case '-':
				{
					if ( (*offset - 1) >= 1 )
					{
						*offset = *offset - 1;
						returnValue = i_PCI3116_WritePotis(boardHandle, 5, *offset);
						if (returnValue != 0)
						{
							printf("Error %d in i_PCI3116_WritePotis\n", returnValue);
							return -1;
						}
					}
				}
				break;
			case VK_RETURN:
				{
					/* ok */
					printf("\n");
					return 0;
				}
				break;
		}
	}

	return 0;
}

/**
* Do the gain calibration around 9.995 V
**/
INT doGainCalibration(HANDLE boardHandle, DWORD * gain, DWORD * offset)
{
	INT returnValue = 0;

	/* write the analog output value as 9.995 V */
	returnValue = i_PCI3116_Write1AnalogOutput(boardHandle, 0, 1, 4095);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_Write1AnalogOutput\n", returnValue);
		return -1;
	}
	else
	{
		printf("i_PCI3116_Write1AnalogOutput OK \n");
	}
	
	printf("\nPlease measure the analog output 0 voltage (between pins 30 and 12).\n");
	printf("Press the + and - keys to set 9,995V, then press enter.\n");

	while(1)
	{
		printf("\rGain: %4d\tOffset: %4d", *gain, *offset);
		switch( _getch() )
		{
			case '+':
				{
					if ( (*gain + 1) <= 255 )
					{
						*gain = *gain + 1;
						returnValue = i_PCI3116_WritePotis(boardHandle, 4, *gain);
						if (returnValue != 0)
						{
							printf("Error %d in i_PCI3116_WritePotis\n", returnValue);
							return -1;
						}
					}
				}
				break;
			case '-':
				{
					if ( (*gain - 1) >= 1 )
					{
						*gain = *gain - 1;
						returnValue = i_PCI3116_WritePotis(boardHandle, 4, *gain);
						if (returnValue != 0)
						{
							printf("Error %d in i_PCI3116_WritePotis\n", returnValue);
							return -1;
						}
					}
				}
				break;
			case VK_RETURN:
				{
					/* ok */
					printf("\n");
					return 0;
				}
				break;
		}
	}

	return 0;
}

/* entry point */
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE boardHandle = NULL;
	DWORD origGain = 0, origOffset = 0;
	int stage = 0;

	/* open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d opening the board \n", returnValue);
		_getch();
		return -1;
	}

	/* read the original value of the offset */
	returnValue = i_PCI3116_ReadPotis(boardHandle, 5, &origOffset);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_ReadPotis\n", returnValue);
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}
	else
	{
		printf("i_PCI3116_ReadPotis OK \n");
	}

	/* read the original value of the gain */
	returnValue = i_PCI3116_ReadPotis(boardHandle, 4, &origGain);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_ReadPotis\n", returnValue);
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}
	else
	{
		printf("i_PCI3116_ReadPotis OK \n");
	}


	/* calibration of the offset - 0V */
	returnValue = doOffsetCalibration( boardHandle, &origGain, &origOffset);
	if ( returnValue != 0)
	{
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* calibration of the gain - 9.995V */
	returnValue = doGainCalibration( boardHandle, &origGain, &origOffset);
	if ( returnValue != 0)
	{
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* calibration of the offset - 0V */
	returnValue = doOffsetCalibration( boardHandle, &origGain, &origOffset);
	if ( returnValue != 0)
	{
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}

	/* save the potis value in the eeprom */
	returnValue = i_PCI3116_SavePotis(boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_SavePotis\n", returnValue);
		i_PCI3116_CloseBoard(boardHandle);
		_getch();
		return -1;
	}
	else
	{
		printf("i_PCI3116_SavePotis OK \n");
	}
	
	/* close the board */
	returnValue = i_PCI3116_CloseBoard(boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_CloseBoard \n", returnValue);
	}
	else
	{
		printf("i_PCI3116_CloseBoard OK \n");
	}

	printf("Hit a key to exit this program...\n");
	_getch();

	return 0;
}
