// Here goes prototypes declaration and documentation

#include <windows.h>
#include "define.h" /* this include file stores typedef that can be easily used */

#ifdef __cplusplus 
	extern "C" {
#endif


/** \defgroup PCI3116 xPCI-3116 functions 
 * @{
 *		\addtogroup General xPCI-3116 general functions 
 *		\ingroup PCI3116 
 *		@{ 
 */
 
/**  Enables to get the number of xPCI-3116 boards present in the system. \n
 * The function fill the value pointed by pb_NbrOfBoards with the number of boards present.
 *                                                                            
 * @param[out] pb_NbrOfBoards Value that will be filled with the number of boards     
 * @retval	0 : No error
 * @retval -1 : Error while getting the number of boards
 */
_INT_ i_PCI3116_GetNumberOfBoards (PBYTE	pb_NbrOfBoards );

/** Get device information of the board.
 *                                                                   
 * @param[in] b_BoardIndex : Index of the board
 * @param[in] dw_IdentifierStringSize : size of the identifier parameter 
 * @param[out] pc_Identifier: Identifier of the board
 * @param[out] pdw_UINumber : This number is typically a user-perceived slot number, such as a number printed next to the slot on the board, or some other number that makes locating the physical device easier for the user. If the device is on a bus that has no UI number convention, or if the bus driver for the device cannot determine the UI number, this value is 0xFFFFFFFF.
 * @param[out] pdw_DeviceNumber : Device number.
 * @param[out] pdw_BusNumber : Bus number.
 * @param[out] pdw_BaseAddress0 : Base address 0 of the board
 * @param[out] pdw_BaseAddress1 : Base address 1 of the board
 * @param[out] pdw_BaseAddress2 : Base address 2 of the board
 * @param[out] pdw_BaseAddress3 : Base address 3 of the board
 * @param[out] pb_Interrupt : Interrupt line of the board
 * @retval 0 : No error
 * @retval -1 : Unable to open the board via index
 * @retval -2 : Error when calling driver's IOCTL
 */
_INT_ i_PCI3116_GetBoardInformation(BYTE		b_BoardIndex,
									DWORD		dw_IdentifierStringSize,
									PCHAR		pc_Identifier,
									PDWORD		pdw_UINumber,
									PDWORD		pdw_DeviceNumber,
									PDWORD		pdw_BusNumber,
									PDWORD		pdw_BaseAddress0,
									PDWORD		pdw_BaseAddress1,
									PDWORD		pdw_BaseAddress2,
									PDWORD		pdw_BaseAddress3,
									PBYTE		pb_Interrupt );
								   
/** Open the board with the index : b_BoardIndex. A handle is returned to the \n    
 * user which allows to use the driver functions. \n 
 *                                                                                  
 * @param[in] b_BoardIndex : Index of the board to open                             
 * @param[out] ph_DeviceHandle : Handle of the selected xPCI-3116 board for using the functions
 * @retval 0 : No error
 * @retval -1 : Unable to get the number of available boards
 * @retval -2 : Wrong device index parameter. The parameter is too high
 * @retval -3 : Error while getting the device's class
 * @retval -4 : Error while getting informations about the device
 * @retval -5 : Memory allocation error
 * @retval -6 : Get device interface detail error
 * @retval -7 : Error while creating communication handle
 * @retval -8 : Error in the initialization callback function
 */
_INT_ i_PCI3116_OpenBoardViaIndex (BYTE	b_BoardIndex,
								   PHANDLE	ph_DeviceHandle );    

/** Open the board with the indentifier : pc_Identifier. A handle is returned to the \n    
 * user which allows to use the following functions. \n                                                         
 *                                                                                  
 * @param[in] pc_Identifier : Identifier of the board to open
 * @param[out] ph_DeviceHandle : Handle of the board xPCI-3116 for using the functions
 * @retval 0 : No Error
 * @retval -1 : Unable to get the number of available boards
 * @retval -2 : Unable to get the board identifier
 * @retval -3 : Unable to open the board
 * @retval -4 : Identifier not found
 */
_INT_ i_PCI3116_OpenBoardViaIdentifier (PCHAR	pc_Identifier,
										PHANDLE	ph_DeviceHandle );
										
/** Release the handle of the board. Block the access to the board.
 *                                                                   
 * @param[in] h_DeviceHandle    : Handle of the board                
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 */
_INT_ i_PCI3116_CloseBoard (HANDLE	h_DeviceHandle );

/** Return the version of the DLL.
 *                                                                   
 * @param[out] pdw_Version  : Version. sample : 0x01010910 -> version 1.01 september 2010       
 * @retval 0 : No Error
 */
_INT_ i_PCI3116_GetDLLVersion (PDWORD	pdw_Version);

/*Function's Name   : i_PCI3116_GetDeviceDriverVersion*/
/** Return the version of the device driver.
*                                                                   
* @param[in] h_DeviceHandle  : Handle of the board                
* @param[out] pdw_Version  : Version. sample : 0x01011211 -> version 1.01 - 12/2011
* @retval 0 : No Error
* @retval -1 : Error while calling IOCTL function
*/
_INT_ i_PCI3116_GetDeviceDriverVersion(HANDLE h_DeviceHandle, PDWORD pdw_Version);

/*Function's Name   : i_PCI3116_GetSerialNumber*/
/** Return the serial number of the board.
*                                                                   
* @param[in] h_DeviceHandle  : Handle of the board                
* @param[out] pdw_DeviceNumber  : Serial number of the board in decimal
* @retval 0 : No Error
* @retval -1 : timeout
* @retval -100 : Error while calling IOCTL function
*/
_INT_ i_PCI3116_GetSerialNumber(HANDLE h_DeviceHandle, PDWORD pdw_DeviceNumber);

/*Function's Name   : i_PCI3116_GetFirmwareVersion*/
/** Return the firmware version of the board.
*                                                                   
* @param[in] h_DeviceHandle  : Handle of the board                
* @param[out] pdw_FirmwareVersion  : Firmware Version of the Board  Contains the 4 ASCII codes of the configuration
 *               \li bits 0 -> 7   ASCII code (version low)
 *               \li bits 8 -> 15  ASCII code (version high)
 *               \li bits 16 -> 23 ASCII code (functionality name second digit)
 *               \li bits 24 -> 31 ASCII code (functionality name first digit)
 *				 \li to read them select one of the four bits and print it using a char printf("%c", )
* @retval 0 : No Error \n
* @retval -1 : timeout \n
* @retval -100 : Error while calling IOCTL function \n
*/
_INT_ i_PCI3116_GetFirmwareVersion (HANDLE h_DeviceHandle, PDWORD pdw_FirmwareVersion);


/**
/**
 *		@}
 *		
 *		\addtogroup Interrupt xPCI-3116 interrupt management functions 
 * 		\ingroup PCI3116
 *		@{ 
 */
 
/** Install an interrupt callback function.
 * This function will be called each time the board generate an interruption. \n
 * The value of dw_InterruptSource will enable you to determine the source of the interruption:
 * <ul>
 *	<li>0x1: End of sequence interrupt. When you use i_PCI3116_Read1AnalogInput and i_PCI3116_ReadMoreAnalogInputs with interrupt, you will receive this interrupt. The values are then available thanks to pw_Args parameter</li>
 *	<li>0x2: Counter-Timer-Watchdog interrupt. The parameter dw_InterruptMask gives you the index of the component that throws the interrupt.</li>
 *	<li>0x4: DMA interrupt. You will receive this interrupt when using i_PCI3116_InitAndStartAnalogInputSequence. When you get this interrupt, you have to read the data measured by the board by calling the function l_PCI3116_ReadSequenceData (see its own documentation). If your computer is too slow to handle all the data, after a while you will have an internal data fifo overflow (dw_InterruptMask will be 0x4). You can change the size of the internal data fifo in the driver's configuration pages.</li>
 *	<li>0x8: DMA counter overflow. You will receive this interrupt when using i_PCI3116_InitAndStartAnalogInputSequence in non continuous mode</li>
 *	<li>0x10: PLD FIFO overflow. The board is too slow to handle all the data</li>
 * </ul> 
 *
 * @param[in] h_DeviceHandle    : Handle of the board                
 * @param[in] v_FunctionName    : Address of the callback function
 *		\n	\b h_DeviceHandle	: Handle of the board
 *		\n	\b b_FIFOOverflow	: If uc_FIFOOverflow != 0, there are too many untreated interrupts in the kernel FIFO, and any new information is lost
 *		\n	\b dw_InterruptSource : Source of the interrupt
 *		\n	\b dw_InterruptMask	: Source of the interrupt
 *		\n	\b pw_Args			: Values read during the interrupt. Null if DMA interrupt
 *		\n	\b dw_ArgsCount		: Number of values read during the interrupt
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : An interrupt routine was still isntalled. Remove it with i_PCI3116_ResetBoardIntRoutine and retry
 * @retval -3 : Error while creating kill event
 * @retval -4 : Error while creating interrupt event
 * @retval -5 : Error while creating interrupt thread
 * @retval -6 : Error while changing the priority class of the thread
 * @retval -7 : Error while changing the priority of the thread
 * @retval -8 : Error while calling the IOCTL command
 * @retval -9 : Error in the interrupt callback function
 */
_INT_ i_PCI3116_SetBoardIntRoutine (HANDLE	h_DeviceHandle,
									void	(*v_FunctionName)(	HANDLE	h_DeviceHandle,
																BYTE	b_FIFOOverflow,
																DWORD	dw_InterruptSource,
																DWORD	dw_InterruptMask,
																PWORD	pw_Args,
																DWORD	dw_ArgsCount )
);

/** Deinstall the interrupt callback function.
 *
 * @param[in] h_DeviceHandle    : Handle of the board                
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : No interrupt routine installed
 * @retval -3 : Error in the reset interrupt callback function
 */
_INT_ i_PCI3116_ResetBoardIntRoutine (HANDLE	h_DeviceHandle );

/**
 *		@}
 *		
 *		\addtogroup Digital xPCI-3116 digital inputs/outputs functions 
 * 		\ingroup PCI3116
 *		@{ 
 */

/** Read 1 digital input of the board
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board                      
 * @param[in] b_Channel Channel to read (0 to 3)
 * @param[out] pb_Value Status of the digital input
 *
 * @retval 0 : No Error
 * @retval -1 : Invalid channel
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Read1DigitalInput(HANDLE	h_DeviceHandle,
								  BYTE		b_Channel,
								  PBYTE		pb_Value );

/** Read the 4 digital inputs of the board
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 * @param[out] pb_Value Status of the digital inputs
 *
 * @retval 0 : No Error
 * @retval -1 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Read4DigitalInputs(HANDLE	h_DeviceHandle,
								   PBYTE	pb_Value );

/** Set 1 digital output of the board to HIGH
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board                      
 * @param[in] b_Channel Channel to set (0 to 3)
 *
 * @retval 0 : No Error
 * @retval -1 : Wrong channel
 * @retval -3 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Set1DigitalOutputOn(HANDLE	h_DeviceHandle,
								  BYTE		b_Channel );

/** Set 1 digital output of the board to LOW
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board                      
 * @param[in] b_Channel Channel to reset (0 to 3)
 *
 * @retval 0 : No Error
 * @retval -1 : Wrong channel
 * @retval -3 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Set1DigitalOutputOff(HANDLE	h_DeviceHandle,
									 BYTE	b_Channel );

/** Set the digital outputs set in the mask to HIGH
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board                      
 * @param[in] b_Mask Channels to set (0x0 to 0xF)
 *
 * @retval 0 : No Error
 * @retval -1 : Wrong mask
 * @retval -3 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Set4DigitalOutputsOn(HANDLE	h_DeviceHandle,
									 BYTE	b_Mask );

/** Set the digital outputs set in the mask to LOW
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board                      
 * @param[in] b_Mask Channels to reset (0x0 to 0xF)
 *
 * @retval 0 : No Error
 * @retval -1 : Wrong mask
 * @retval -3 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Set4DigitalOutputsOff(HANDLE	h_DeviceHandle,
									  BYTE	b_Mask );

/** Enable the digital output memory \n
 * When digital output memory is enabled, the active channels stay active until calling i_PCI3116_Set1DigitalOutputOff or i_PCI3116_Set4DigitalOutputsOff. \n
 * When digital output memory is disabled, the active channels are reset at each call of i_PCI3116_Set1DigitalOutputOn or i_PCI3116_Set4DigitalOutputsOn.
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 *
 * @retval 0 : No Error
 * @retval -1 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_SetDigitalOutputMemoryOn(HANDLE h_DeviceHandle );

/** Disable the digital output memory \n
 * When digital output memory is enabled, the active channels stay active until calling i_PCI3116_Set1DigitalOutputOff or i_PCI3116_Set4DigitalOutputsOff. \n
 * When digital output memory is disabled, the active channels are reset at each call of i_PCI3116_Set1DigitalOutputOn or i_PCI3116_Set4DigitalOutputsOn.
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 *
 * @retval 0 : No Error
 * @retval -1 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_SetDigitalOutputMemoryOff(HANDLE h_DeviceHandle );

/** Get the status of 1 digital output of the board
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Channel Channel to get (0 to 3)
 * @param[out] pb_OutputsStatus Status of the digital output
 *
 * @retval 0 : No Error
 * @retval -1 : Wrong channel
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Get1DigitalOutputStatus(HANDLE	h_DeviceHandle,
										BYTE	b_Channel,
										PBYTE	pb_OutputsStatus );

/** Get the status of all the digital outputs of the board
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 * @param[out] pb_OutputsStatus Status of the digital output
 *
 * @retval 0 : No Error
 * @retval -1 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Get4DigitalOutputsStatus(HANDLE	h_DeviceHandle,
										 PBYTE	pb_OutputsStatus );

/**
 *		@}
 *		
 *		\addtogroup TTL xPCI-3116 TTL inputs/outputs functions 
 * 		\ingroup PCI3116
 *		@{ 
 */
 
/** Set the TTL programmable port to input or output
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 * @param[out] b_InOrOut Configure the programmable port as input (PCI3116_TTL_INPUT) or output (PCI3116_TTL_OUTPUT)
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Invalid port mode
 * @retval -3 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_SetTTLPortConfiguration(HANDLE	h_DeviceHandle,
										BYTE	b_InOrOut );

/** Read the TTL inputs \n
 * In order to read the programmable port (with parameter PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH), it has to be set as an input first. \n
 * If PCI3116_PORT_INPUT or PCI3116_PORT_PROGRAMMABLE is used, the 8 lowest bits represent the port inputs. \n
 * If PCI3116_PORT_BOTH is used, then the 8 low bits represent the input port, and the 8 high bits the programmable port.
 *                                                                          
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Port Port to read (PCI3116_PORT_INPUT, PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH)
 * @param[out] pw_Value Value of the port.
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Invalid port selection
 * @retval -3 : The programmable port is not configured as an input
 * @retval -4 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadTTLInputs(HANDLE	h_DeviceHandle,
							  BYTE		b_Port,
							  PWORD		pw_Value );

/** Set the TTL outputs to LOW \n
 * In order to set the programmable port (with parameter PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH), it has to be set as an output first. \n
 * If PCI3116_PORT_OUTPUT or PCI3116_PORT_PROGRAMMABLE is used, the 8 lowest bits represent the port outputs. \n
 * If PCI3116_PORT_BOTH is used, then the 8 low bits represent the output port, and the 8 high bits the programmable port.
 *                                                
 
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Port Port to reset (PCI3116_PORT_OUTPUT, PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH)
 * @param[in] w_Mask Outputs to reset (0x00 to 0xFF, or 0x0000 to 0xFFFF if both ports are used)
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Invalid port selection
 * @retval -3 : The programmable port is not configured as an output
 * @retval -4 : Invalid mask
 * @retval -5 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_SetTTLOutputsOff(HANDLE	h_DeviceHandle,
								 BYTE	b_Port,
								 WORD	w_Mask );

/** Set the TTL outputs to HIGH \n
 * In order to set the programmable port (with parameter PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH), it has to be set as an output first. \n
 * If PCI3116_PORT_OUTPUT or PCI3116_PORT_PROGRAMMABLE is used, the 8 lowest bits represent the port outputs. \n
 * If PCI3116_PORT_BOTH is used, then the 8 low bits represent the output port, and the 8 high bits the programmable port.
 *                                                
 
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Port Port to reset (PCI3116_PORT_OUTPUT, PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH)
 * @param[in] w_Mask Outputs to reset (0x00 to 0xFF, or 0x0000 to 0xFFFF if both ports are used)
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Invalid port selection
 * @retval -3 : The programmable port is not configured as an output
 * @retval -4 : Invalid mask
 * @retval -5 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_SetTTLOutputsOn(HANDLE	h_DeviceHandle,
								BYTE	b_Port,
								WORD	w_Mask );

/** Get the TTL outputs status \n
 * In order to set the programmable port (with parameter PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH), it has to be set as an output first. \n
 * If PCI3116_PORT_OUTPUT or PCI3116_PORT_PROGRAMMABLE is used, the 8 lowest bits represent the port outputs. \n
 * If PCI3116_PORT_BOTH is used, then the 8 low bits represent the output port, and the 8 high bits the programmable port.
 *                                                
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Port Port to reset (PCI3116_PORT_OUTPUT, PCI3116_PORT_PROGRAMMABLE or PCI3116_PORT_BOTH)
 * @param[out] pw_OutputsStatus Outputs status (0x00 to 0xFF, or 0x0000 to 0xFFFF if both ports are used)
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Invalid port selection
 * @retval -3 : The programmable port is not configured as an output
 * @retval -4 : Invalid mask
 * @retval -5 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_GetTTLOutputsStatus(HANDLE	h_DeviceHandle,
									BYTE	b_Port,
									PWORD	pw_OutputsStatus );

/**
 *		@}
 *		
 *		\addtogroup TCW xPCI-3116 Timer/Counter/Watchdog functions 
 * 		\ingroup PCI3116
 *		@{ 
 */

/**
* Enables to start a counter, timer or watchdog. \n
* Three hardware components are available. A hardware component may only implement one function at a time.\n
* The first component (index 0) can ony be used as counter and timer.\n
* The two last components (index 1 and index 2) can be used as counter, timer and watchdog.\n
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_Function Function choosed for the component. (PCI3116_COUNTER_FUNCTION, PCI3116_TIMER_FUNCTION, PCI3116_WATCHDOG_FUNCTION )
* @param[in] b_Index Index of the component (0, 1, or 2). (Note: index 0 cannot work if b_Function is PCI3116_WATCHDOG_FUNCTION)
* @param[in] b_InterruptEnabled Enable to use or not use an interrupt (0,1).
* @param[in] w_ReloadValue For the counter: its maximum value. For timer and watchdog: the time to count (depend on b_TimerWatchdogTimeBase)
* @param[in] b_TimerWatchdogTimeBase Only use if b_Function is PCI3116_TIMER_FUNCTION or PCI3116_WATCHDOG_FUNCTION. Select the time base (PCI3116_TIME_BASE_MICROSECONDS, PCI3116_TIME_BASE_MILLISECONDS, PCI3116_TIME_BASE_SECONDS)
* @param[in] b_CounterTimerOutputMode Ony use if b_Function is PCI3116_COUNTER_FUNCTION or PCI3116_TIMER_FUNCTION. Set the way the output will change (PCI3116_OUTPUT_ENABLED, PCI3116_OUTPUT_DISABLED, PCI3116_OUTPUT_INVERTED)
* @param[in] b_TimerMode Only use if b_Function is PCI3116_TIMER_FUNCTION. Specifiy the mode of the timer. (PCI3116_TIMER_MODE_2, PCI3116_TIMER_MODE_3). \n
* PCI3116_TIMER_MODE_2: It functions like a divide-by-w_ReloadValue counter. It is used to generate a real time clock interrupt. OUT is initially high after the initialization. When the initial count has decremented to 1, OUT goes low for one CLK pulse. OUT then goes high again, the counter reloads the initial count (w_ReloadValue) and the process is repeated. This action can generate an interrupt. \n
* PCI3116_TIMER_MODE_3: This mode is similar to mode 2 except for the duty cycle of OUT. OUT will initially be high after the initialisation. When the initial count (ul_ReloadValue) has expired, OUT goes low for the next sequence. When the initial count (ul_ReloadValue) of that sequence has expired, OUT goes high again for the following sequence. The mode is periodic; the sequence above is repeated indefinitely. \n
* @param[in] b_CounterDirection Only use if b_Function is PCI3116_COUNTER_FUNCTION. (PCI3116_COUNTER_DIRECTION_UP, PCI3116_COUNTER_DIRECTION_DOWN). Selects the counter for up-counting or down-counting
* @param[in] b_CounterLevel Only use if b_Function is PCI3116_COUNTER_FUNCTION. (PCI3116_COUNTER_LOW_LEVEL, PCI3116_COUNTER_HIGH_LEVEL, PCI3116_COUNTER_BOTH_LEVEL). Counter counts low levels, or high levels or both.
* @retval 0 : success
* @retval -1 : b_Function is invalid
* @retval -2 : index 0 cannot be used as watchdog
* @retval -3 : b_InterruptEnabled is invalid
* @retval -4 : b_Index is invalid
* @retval -5 : b_TimerWatchdogTimeBase is invalid
* @retval -11 : b_CounterDirection is invalid
* @retval -12 : b_CounterLevel is invalid
* @retval -13 : b_CounterTimerOutputMode is invalid
* @retval -14 : Error while calling IOCTL function (wrong handle ?)
* @retval -21 : b_CounterTimerOutputMode is invalid
* @retval -22 : b_TimerMode is invalid
* @retval -23 : Error while calling IOCTL function (wrong handle ?)
* @retval -31 : Error while calling IOCTL function (wrong handle ?)
**/
_INT_ i_PCI3116_InitAndStartCounterTimerWatchdog(HANDLE h_DeviceHandle,
												 BYTE b_Function,
												 BYTE b_Index,
												 BYTE b_InterruptEnabled,
												 WORD w_ReloadValue,
												 BYTE b_TimerWatchdogTimeBase,
												 BYTE b_CounterTimerOutputMode,
												 BYTE b_TimerMode,
												 BYTE b_CounterDirection,
												 BYTE b_CounterLevel );

/** Stops the timer/counter/watchdog \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Counter/timer/watchdog to stop (0,1 or 2)
 *
 * @retval 0 : No Error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_StopCounterTimerWatchdog(HANDLE	h_DeviceHandle,
										 BYTE	b_Index);

/** Triggers the timer/counter/watchdog \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Counter/timer/watchdog to trigger (0,1 or 2)
 *
 * @retval 0 : No Error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_TriggerCounterTimerWatchdog(HANDLE	h_DeviceHandle,
											BYTE	b_Index);

/** Reads the counter status \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Timer to use (PCI3116_TIMER_0, PCI3116_TIMER_1 or PCI3116_TIMER_2)
 * @param[out] pb_CounterStatus Timer status (0 = disabled, 1 = enabled)
 * @param[out] pb_Clear Status of the CLEAR bit (0 = counter has not been cleared, 1 = counter has been cleared)
 * @param[out] pb_SoftwareTriggerStatus Status of the software trigger (0 = no software trigger occured, 1 = software trigger occured)
 * @param[out] pw_CounterValue Current value of the counter
 *
 * @retval 0 : No Error
 * @retval -1 : b_CounterSelect is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadCounterStatus (HANDLE	h_DeviceHandle,
								   BYTE		b_Index,
								   PBYTE	pb_CounterStatus,
								   PBYTE	pb_Clear,
								   PBYTE	pb_SoftwareTriggerStatus,
								   PWORD	pw_CounterValue );

/** Read the value of the counter \n
 * 
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Counter to use (PCI3116_TIMER_0, PCI3116_TIMER_1 or PCI3116_TIMER_2)
 * @param[out] pw_CounterValue Current value of the counter
 *
 * @retval 0 : No error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadCounterValue (HANDLE	h_DeviceHandle,
								   BYTE		b_Index,
								   PWORD	pw_CounterValue );

/** Clear the counter \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Watchdog to use (PCI3116_TIMER_0, PCI3116_TIMER_1 or PCI3116_TIMER_2)
 *
 * @retval 0 : No Error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ClearCounter(HANDLE	h_DeviceHandle,
							 BYTE	b_Index );

/** Reads the timer status \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Timer to use (PCI3116_TIMER_0, PCI3116_TIMER_1 or PCI3116_TIMER_2)
 * @param[out] pb_TimerStatus Timer status (0 = disabled, 1 = enabled)
 * @param[out] pb_SoftwareTriggerStatus Status of the software trigger (0 = no software trigger occured, 1 = software trigger occured)
 * @param[out] pw_TimerValue Current value of the timer
 *
 * @retval 0 : No Error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadTimerStatus (HANDLE	h_DeviceHandle, 
								 BYTE	b_Index, 
								 PBYTE	pb_TimerStatus, 
								 PBYTE	pb_SoftwareTriggerStatus, 
								 PWORD	pw_TimerValue);

/** Read the value of the timer \n
 * 
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Timer to use (PCI3116_TIMER_0, PCI3116_TIMER_1 or PCI3116_TIMER_2)
 * @param[out] pw_TimerValue Current value of the timer
 *
 * @retval 0 : No error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadTimerValue (HANDLE	h_DeviceHandle,
								BYTE	b_Index,
								PWORD	pw_TimerValue );

/** Reads the watchdog status \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Watchdog to use (PCI3116_TIMER_1 or PCI3116_TIMER_2)
 * @param[out] pb_WatchdogStatus Watchdog status (0 = disabled, 1 = enabled)
 * @param[out] pb_SoftwareTriggerStatus Status of the software trigger (0 = no software trigger occured, 1 = software trigger occured)
 * @param[out] pw_WatchdogValue Current value of the watchdog
 *
 * @retval 0 : No Error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadWatchdogStatus(HANDLE	h_DeviceHandle,
								   BYTE		b_Index,
								   PBYTE	pb_WatchdogStatus,
								   PBYTE	pb_SoftwareTriggerStatus,
								   PWORD	pw_WatchdogValue);

/** Read the value of the watchdog \n
 * 
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Index Watchdog to use (PCI3116_TIMER_1 or PCI3116_TIMER_2)
 * @param[out] pw_WatchdogValue Current value of the watchdog
 *
 * @retval 0 : No error
 * @retval -1 : b_Index is invalid
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadWatchdogValue (HANDLE	h_DeviceHandle,
								   BYTE	b_Index,
								   PWORD	pw_WatchdogValue );

/**
 *		@}
 *		
 *		\addtogroup Analog xPCI-3116 Analog inputs/outputs functions 
 * 		\ingroup PCI3116
 *		@{ 
 */

 /** Write the value of one analog output of the board\n
 * In unipolar mode, output voltage range is 0V to 10V \n
 * In bipolar mode, output voltage range is -10V to 10V \n
 * Analog output values are 0x0 to 0x7FF in unipolar mode, 0x0 to 0xFFF in bipolar mode
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Channel Channel to write (0 to 3)
 * @param[in] b_Polarity Polarity of the channel (PCI3116_OUTPUT_MODE_UNIPOLAR or PCI3116_OUTPUT_MODE_BIPOLAR)
 * @param[in] w_Value Value to write to the output
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -3 : Invalid channel
 * @retval -4 : Invalid polarity
 * @retval -5 : Invalid value in bipolar mode
 * @retval -6 : Invalid value in unipolar mode
 * @retval -7 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Write1AnalogOutput(HANDLE	h_DeviceHandle,
								   BYTE		b_Channel,
								   BYTE		b_Polarity,
								   WORD		w_Value );
 
 /** Write values of several analog outputs \n
 * In unipolar mode, output voltage range is 0V to 10V \n
 * In bipolar mode, output voltage range is -10V to 10V \n
 * Analog output values are 0x0 to 0x7FF in unipolar mode, 0x0 to 0xFFF in bipolar mode
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ChannelNbr Number of channels to write (1 to 4)
 * @param[in] pb_Channels Channels to write (0 to 3)
 * @param[in] pb_Polarity Polarity of the channel (PCI3116_OUTPUT_MODE_UNIPOLAR or PCI3116_OUTPUT_MODE_BIPOLAR)
 * @param[in] pw_Value Value to write to the output
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : b_ChannelNbr is invalid
 * @retval -3 : Invalid channel
 * @retval -4 : Invalid polarity
 * @retval -5 : Invalid value in bipolar mode
 * @retval -6 : Invalid value in unipolar mode
 * @retval -7 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_WriteMoreAnalogOutputs(HANDLE	h_DeviceHandle, 
									   BYTE		b_ChannelNbr, 
									   PBYTE	pb_Channels, 
									   PBYTE	pb_Polarity,
									   PWORD	pw_Value);
 
 /** Set analog input mode to single-ended or differential input \n
 * The input mode has to be set at least once before any call to an analog input function. \n
 * Once set, the configuration will last until the program ends, or another mode is set. \n
 * \n
 * In single-ended mode, 16 analog inputs are available. \n
 * In differential mode, there are only 8 analog inputs available. \n
 * Please refer to the manual for further information. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_InputMode Input mode (PCI3116_INPUT_MODE_SINGLE_ENDED or PCI3116_INPUT_MODE_DIFFERENTIAL)
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Invalid input mode
 */
_INT_ i_PCI3116_SetAnalogInputMode(HANDLE	h_DeviceHandle,
								   BYTE		b_InputMode );
 
 /** Get analog input mode (single-ended or differential input) \n
 * \n
 * In single-ended mode, 16 analog inputs are available. \n
 * In differential mode, there are only 8 analog inputs available. \n
 * Please refer to the manual for further information. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[out] pb_InputMode Input mode (PCI3116_INPUT_MODE_UNDEFINED, PCI3116_INPUT_MODE_SINGLE_ENDED or PCI3116_INPUT_MODE_DIFFERENTIAL)
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 */
_INT_ i_PCI3116_GetAnalogInputMode(HANDLE	h_DeviceHandle,
								   PBYTE	pb_InputMode );

 /** Initialize and starts an analog acquisition \n
 * To use this function you must set an interrupt routine where you will handle the data, and you must also define the input mode. \n
 * Gain acts as a multiplier for the input voltage. Possible gain values are :
 * <ul>
 * 	<li> \b PCI3116_GAIN_1 : Input range is between -10V and 10V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_2 : Input range is between -5V and 5V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_5 : Input range is between -2V and 2V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_10 : Input range is between -1V and 1V (bipolar)</li>
 * </ul>
 * The converting time stands for the time spent to acquire one channel. The time to acquire a sequence is dw_ConvertingTime * b_ChannelCount \n
 * The software trigger is a combination of 2 parameters
 * <ul>
 * 	<li>The first one enables or disabled the trigger</li>
 *	<ul>
 *	 	<li> \b PCI3116_SOFT_TRIGGER_ENABLED : The trigger is enabled</li>
 *		<li> \b PCI3116_SOFT_TRIGGER_DISABLED : The trigger is disabled</li>
 *	</ul>
 * 	<li>The trigger type is selected with one of the following parameters</li>
 * 	<ul>
 *		<li> \b PCI3116_TRIGGER_ONE_SHOT : The acquisition starts when the trigger is set</li>
 * 		<li> \b PCI3116_TRIGGER_SEQUENCE_TRIGGER : A pre-defined number of sequence is acquired : dw_SequenceTriggerCount</li>
 * 		<li> \b PCI3116_TRIGGER_SINGLE_SEQUENCE : One whole sequence is read for each trigger</li>
 *	</ul>
 * </ul>
 * The external trigger is a combination of the following parameters :
 * <ul>
 * 	<li>The first one defines the trigger edge</li>
 *	<ul>
 *		<li> \b PCI3116_EXT_TRIGGER_DISABLED : Trigger is disabled</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_LOW : Triggers on low edge</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_HIGH : Triggers on high edge</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_BOTH : Triggers on both edges</li>
 *	</ul>
 *	<li>The second one defines the trigger type</li>
	<ul>
 *		<li> \b PCI3116_TRIGGER_ONE_SHOT : The acquisition starts when the trigger is set</li>
 *		<li> \b PCI3116_TRIGGER_SEQUENCE_TRIGGER : A pre-defined number of sequence is acquired : dw_SequenceTriggerCount</li>
 *		<li> \b PCI3116_TRIGGER_SINGLE_SEQUENCE : One whole sequence is read for each trigger</li>
 * 	</ul>
 * </ul>
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] dw_SequenceCount: The total number of sequence to acquire. Set it to 0 if you want to use continuous acquisition (i.e. infinite acquisition)
 * @param[in] dw_SequenceBeforeInterrupt: Specify the number of sequence to wait before generating an interruption. For high frequency, set a high number (512 if using maximum frequency for example).
 * @param[in] b_ChannelCount: The number of channels in one sequence. Rule: (b_ChannelCount * dw_SequenceBeforeInterrupt) must be a multiple of 2
 * @param[in] pb_Channel Define the channels in the sequence (single ended : 0 to 15, differential : 0 to 7). Depending on your board, this number may be different.
 * @param[in] pb_Gain Define the gain for each channel
 * @param[in] pb_Polarity Define the polarity for each channel (PCI3116_OUTPUT_MODE_UNIPOLAR or PCI3116_OUTPUT_MODE_BIPOLAR)
 * @param[in] dw_ConvertingTime Define the time between two channels acquisition (5us to 65 535 000us). If you choose 16 channels with a conversion time of 5us, an entire sequence will be acquired in 16 * 5 = 80us
 * @param[in] dw_DelayTime Define the time between two sequences acquisition (5us to 65 535 000us).
 * @param[in] b_SoftTriggerMode Defines the software trigger
 * @param[in] b_ExtTriggerMode Defines the external trigger
 * @param[in] dw_SequenceTriggerCount If you choose a trigger with mode PCI3116_TRIGGER_SEQUENCE_TRIGGER, it defines the number of sequence to acquire when a trigger occurs (1 to 0xFFFFFFFF). If not use, give 0.
 * @retval 0 : success
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The sequence size is wrong
 * @retval -3 : The input mode has not been set
 * @retval -4 : A channel index is invalid (single-ended mode)
 * @retval -5 : A gain value is wrong
 * @retval -6 : A polarity value is wrong
 * @retval -7 : The converting time is invalid
 * @retval -8 : The delay time is invalid
 * @retval -9 : The interrupt routine is not installed
 * @retval -10 : dw_SequenceBeforeInterrupt is not valid
 * @retval -11 : (b_ChannelCount * dw_SequenceBeforeInterrupt) is not a multiple of 2
 * @retval -12 : both software and hardware trigger are enabled. In that case, they must have the same type (one shot, sequence trigger or single sequence)
 * @retval -13 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_InitAndStartAnalogInputSequence(HANDLE	h_DeviceHandle,
												DWORD	dw_SequenceCount,
												DWORD	dw_SequenceBeforeInterrupt,
												BYTE	b_ChannelCount,
												PBYTE	pb_Channel,
												PBYTE	pb_Gain,
												PBYTE	pb_Polarity,
												DWORD	dw_ConvertingTime,
												DWORD	dw_DelayTime,
												BYTE	b_SoftTriggerMode,
												BYTE	b_ExtTriggerMode,
												DWORD	dw_SequenceTriggerCount);

 /** Read analog inputs from the board \n
 * You must call the set analog input mode function before calling this function. \n
 * Gain acts as a multiplier for the input voltage. Possible gain values are :
 * <ul>
 * 	<li> \b PCI3116_GAIN_1 : Input range is between -10V and 10V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_2 : Input range is between -5V and 5V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_5 : Input range is between -2V and 2V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_10 : Input range is between -1V and 1V (bipolar)</li>
 * </ul>
 * The converting time stands for the time spent to acquire one channel. The time to acquire a sequence is ul_ConvertingTime * uc_ChannelCount \n
 * The software trigger is a combination of 2 parameters
 * <ul>
 * 	<li>The first one enables or disabled the trigger</li>
 *	<ul>
 *	 	<li> \b PCI3116_SOFT_TRIGGER_ENABLED : The trigger is enabled</li>
 *		<li> \b PCI3116_SOFT_TRIGGER_DISABLED : The trigger is disabled</li>
 *	</ul>
 * 	<li>The trigger type is selected with one of the following parameters</li>
 * 	<ul>
 *		<li> \b PCI3116_TRIGGER_ONE_SHOT : The acquisition starts when the trigger is set</li>
 *	</ul>
 * </ul>
 * The external trigger is a combination of the following parameters :
 * <ul>
 * 	<li>The first one defines the trigger edge</li>
 *	<ul>
 *		<li> \b PCI3116_EXT_TRIGGER_DISABLED : Trigger is disabled</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_LOW : Triggers on low edge</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_HIGH : Triggers on high edge</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_BOTH : Triggers on both edges</li>
 *	</ul>
 *	<li>The second one defines the trigger type</li>
	<ul>
 *		<li> \b PCI3116_TRIGGER_ONE_SHOT : The acquisition starts when the trigger is set</li>
 * 	</ul>
 * </ul>
 * If the interrupts are enabled, the function returns, and the value can be read in the interrupt routine once available. \n
 * If the interrupts are disabled, the function waits for the results and return the values in the pus_ChannelValue parameter. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ChannelCount Set the number of channels in a sequence (1 to 16)
 * @param[in] pb_Channel Define the channels in the sequence (single ended : 0 to 15, differential : 0 to 7)
 * @param[in] pb_Gain Define the gain for each channel
 * @param[in] pb_Polarity Define the polarity for each channel (PCI3116_OUTPUT_MODE_UNIPOLAR or PCI3116_OUTPUT_MODE_BIPOLAR)
 * @param[in] dw_ConvertingTime Define the tine between two channels acquisition (5us to 65 535 000us)
 * @param[in] b_InterruptFlag Enable the interrupts
 * @param[in] b_SoftTriggerMode Defines the software trigger
 * @param[in] b_ExtTriggerMode Defines the external trigger
 * @param[out] pw_ChannelValue Value of the sequence, if interrupts are disabled
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The sequence size is wrong
 * @retval -3 : The input mode has not been set
 * @retval -4 : A channel index is invalid (single-ended mode)
 * @retval -5 : A channel index is invalid (differential mode)
 * @retval -6 : A gain value is wrong
 * @retval -7 : A polarity value is wrong
 * @retval -8 : The converting time is invalid
 * @retval -9 : The interrupt routine is not installed
 * @retval -10 : The software trigger is invalid
 * @retval -11 : The external trigger is invalid
 * @retval -12 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_ReadMoreAnalogInputs (HANDLE	h_DeviceHandle,
									  BYTE		b_ChannelCount,
									  PBYTE		pb_Channel,
									  PBYTE		pb_Gain,
									  PBYTE		pb_Polarity,
									  DWORD		dw_ConvertingTime,
									  BYTE		b_InterruptFlag,
									  BYTE		b_SoftTriggerMode,
									  BYTE		b_ExtTriggerMode,
									  PWORD		pw_ChannelValue );

  /** Read one analog input from the board \n
 * You must call the set analog input mode function before calling this function. \n
 * Gain acts as a multiplier for the input voltage. Possible gain values are :
 * <ul>
 * 	<li> \b PCI3116_GAIN_1 : Input range is between -10V and 10V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_2 : Input range is between -5V and 5V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_5 : Input range is between -2V and 2V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_10 : Input range is between -1V and 1V (bipolar)</li>
 * </ul>
 * The converting time stands for the time spent to acquire one channel. The time to acquire a sequence is ul_ConvertingTime * uc_ChannelCount \n
 * The software trigger is a combination of 2 parameters
 * <ul>
 * 	<li>The first one enables or disabled the trigger</li>
 *	<ul>
 *	 	<li> \b PCI3116_SOFT_TRIGGER_ENABLED : The trigger is enabled</li>
 *		<li> \b PCI3116_SOFT_TRIGGER_DISABLED : The trigger is disabled</li>
 *	</ul>
 * 	<li>The trigger type is selected with one of the following parameters</li>
 * 	<ul>
 *		<li> \b PCI3116_TRIGGER_ONE_SHOT : The acquisition starts when the trigger is set</li>
 *	</ul>
 * </ul>
 * The external trigger is a combination of the following parameters :
 * <ul>
 * 	<li>The first one defines the trigger edge</li>
 *	<ul>
 *		<li> \b PCI3116_EXT_TRIGGER_DISABLED : Trigger is disabled</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_LOW : Triggers on low edge</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_HIGH : Triggers on high edge</li>
 *		<li> \b PCI3116_EXT_TRIGGER_ENABLED_BOTH : Triggers on both edges</li>
 *	</ul>
 *	<li>The second one defines the trigger type</li>
	<ul>
 *		<li> \b PCI3116_TRIGGER_ONE_SHOT : The acquisition starts when the trigger is set</li>
 * 	</ul>
 * </ul>
 * If the interrupts are enabled, the function returns, and the value can be read in the interrupt routine once available. \n
 * If the interrupts are disabled, the function waits for the results and return the values in the pus_ChannelValue parameter. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_Channel Define the channel to acquire (single ended : 0 to 15, differential : 0 to 7)
 * @param[in] b_Gain Define the gain for the channel
 * @param[in] b_Polarity Define the polarity for the channel (PCI3116_OUTPUT_MODE_UNIPOLAR or PCI3116_OUTPUT_MODE_BIPOLAR)
 * @param[in] dw_ConvertingTime Define the time needed to acquire the channel (5us to 65 535 000us)
 * @param[in] b_InterruptFlag Enable the interrupts
 * @param[in] b_SoftTriggerMode Defines the software trigger
 * @param[in] b_ExtTriggerMode Defines the external trigger
 * @param[out] pw_ChannelValue Value of the channel, if interrupts are disabled
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -3 : The input mode has not been set
 * @retval -4 : A channel index is invalid (single-ended mode)
 * @retval -5 : A channel index is invalid (differential mode)
 * @retval -6 : A gain value is wrong
 * @retval -7 : A polarity value is wrong
 * @retval -8 : The converting time is invalid
 * @retval -9 : The interrupt routine is not installed
 * @retval -10 : The software trigger is invalid
 * @retval -11 : The external trigger is invalid
 * @retval -12 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_Read1AnalogInput (HANDLE	h_DeviceHandle,
								  BYTE		b_Channel,
								  BYTE		b_Gain,
								  BYTE		b_Polarity,
								  DWORD		dw_ConvertingTime,
								  BYTE		b_InterruptFlag,
								  BYTE		b_SoftTriggerMode,
								  BYTE		b_ExtTriggerMode,
								  PWORD		pw_ChannelValue );

 /** Starts an auto-refresh acquisition \n
 * You must call the set analog input mode function before calling this function. \n
 * Auto-refresh mode is started once, and returns an array of values, each one corresponding to a channel. \n
 * These values are automatically refreshed after each conversion cycle, so the values in this array are always the latest ones. \n
 * Gain acts as a multiplier for the input voltage. Possible gain values are :
 * <ul>
 * 	<li> \b PCI3116_GAIN_1 : Input range is between -10V and 10V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_2 : Input range is between -5V and 5V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_5 : Input range is between -2V and 2V (bipolar)</li>
 * 	<li> \b PCI3116_GAIN_10 : Input range is between -1V and 1V (bipolar)</li>
 * </ul>
 * The converting time stands for the time spent to acquire one channel. The time to acquire a sequence is dw_ConvertingTime * b_ChannelCount \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ChannelCount Set the number of channels in a sequence (1 to 16)
 * @param[in] pb_Channel Define the channels in the sequence (single ended : 0 to 15, differential : 0 to 7)
 * @param[in] pb_Gain Define the gain for each channel
 * @param[in] pb_Polarity Define the polarity for each channel (PCI3116_OUTPUT_MODE_UNIPOLAR or PCI3116_OUTPUT_MODE_BIPOLAR)
 * @param[in] dw_ConvertingTime Define the tine between two channels acquisition (5us to 65 535 000us)
 * @param[out] ppdw_Channels Pointer to an array that contains the value of each channels
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The sequence size is wrong
 * @retval -3 : The input mode has not been set
 * @retval -4 : A channel index is invalid (single-ended mode)
 * @retval -5 : A channel index is invalid (differential mode)
 * @retval -6 : A gain value is wrong
 * @retval -7 : A polarity value is wrong
 * @retval -8 : The converting time is invalid
 * @retval -9 : Error while calling IOCTL function (wrong handle ?)
 * @retval -20 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_InitAndStartAutoRefreshAcquisition(HANDLE	h_DeviceHandle,
								 BYTE	b_ChannelCount,
								 PBYTE	pb_Channel,
								 PBYTE	pb_Gain,
								 PBYTE	pb_Polarity,
								 DWORD	dw_ConvertingTime,
								 PDWORD	*ppdw_Channels );
	
/** Stops any analog acquisition \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 *
 * @retval 0 : No Error
 * @retval -1 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_StopAnalogAcquisition(HANDLE	h_DeviceHandle );

/** Triggers any analog acquisition \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 *
 * @retval 0 : No Error
 * @retval -1 : Error while calling IOCTL function (wrong handle ?)
 */
_INT_ i_PCI3116_TriggerAnalogAcquisition(HANDLE	h_DeviceHandle );

/** Get the number of analog inputs available on this board
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[out] pb_NumberOfInputChannels Number of analog inputs available on this board
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 */
_INT_ i_PCI3116_GetAnalogInputChannelsNbr(HANDLE	h_DeviceHandle,
										 PBYTE	pb_NumberOfInputChannels );

/** Get the resolution of the analog inputs of this board, in bits
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[out] pb_Resolution Resolution of the analog inputs of this board, in bits
 *
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 */
_INT_ i_PCI3116_GetAnalogInputResolution(HANDLE	h_DeviceHandle,
										 PBYTE	pb_Resolution );
										 									 
/**
* Enables to read data acquired by a sequence acquisition. \n
* This function can be called in the interrupt routine that you registered. (see samples) \n
* @param h_DeviceHandle: handle to the board
* @param dw_Size: size of data to read. To be powerfull, should be ( sequence size * sequence before interrupt ) * sizeof ( USHORT )
* @param pv_Data: pointer on data buffer where the acquired data will be stored  
* @retval >= 0:	size of data read
* @retval -1: error while reading
**/
_LONG_ l_PCI3116_ReadSequenceData(HANDLE h_DeviceHandle,
						 DWORD dw_Size,
						 PVOID pv_Data);


/**
 * Reads the value of a digital potentiometer (for calibration purposes)
 * @param h_DeviceHandle: handle to the board
 * @param b_PotisId: the ID number of the potentiometer to be read
 * <ul>
 * 	<li> \b 0 : Offset poti bipolar </li>
 * 	<li> \b 1 : Offset poti unipolar </li>
 * 	<li> \b 2 : Gain poti unipolar </li>
 * 	<li> \b 3 : Gain poti bipolar </li>
 * 	<li> \b 4 : Analog output gain </li>
 * 	<li> \b 5 : Analog output offset </li>
 * </ul>
 * @param pdw_Value: A pointer to a value that will be filled with the read value
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The potis id parameter is wrong
 * @retval -3 : Error while calling IOCTL function (wrong handle ?)
**/
_INT_ i_PCI3116_ReadPotis(HANDLE h_DeviceHandle, BYTE b_PotisId, PDWORD pdw_Value);

/**
 * Writes the value of a digital potentiometer (for calibration purposes)
 * @param h_DeviceHandle: handle to the board
 * @param b_PotisId: the ID number of the potentiometer to be written
 * <ul>
 * 	<li> \b 0 : Offset poti bipolar </li>
 * 	<li> \b 1 : Offset poti unipolar </li>
 * 	<li> \b 2 : Gain poti unipolar </li>
 * 	<li> \b 3 : Gain poti bipolar </li>
 * 	<li> \b 4 : Analog output gain </li>
 * 	<li> \b 5 : Analog output offset </li>
 * </ul>
 * @param dw_Value: The value to be written (0-255)
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The potis id parameter is wrong
 * @retval -3 : The value parameter is wrong
 * @retval -4 : Error while calling IOCTL function (wrong handle ?)
**/
_INT_ i_PCI3116_WritePotis(HANDLE h_DeviceHandle, BYTE b_PotisId, DWORD dw_Value);

/**
 * Save the values of the digital potentiometers in the EEPROM (for calibration purposes)
 * @param h_DeviceHandle: handle to the board
 * @retval 0 : No Error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Error while calling IOCTL function (wrong handle ?)
**/
_INT_ i_PCI3116_SavePotis(HANDLE h_DeviceHandle);

/**
 *		@}
 */

/**
 *	@}
 */	
#ifdef __cplusplus
	}
#endif
