/**
* Demonstrate how to configure, start and get the value of a timer
**/
#include "stdafx.h"

/* entry point */
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT	returnValue = 0;
	HANDLE boardHandle = NULL;
	ULONG readValue = 0;
	BYTE timerIndex = 0;
	BYTE timerMode = 0;
	BYTE outputMode = 0;
	BYTE enableInterrupt = 0;
	BYTE timeBase = 0;
	WORD reloadValue = 0;
	int doContinue = 1;
	
	/* open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d opening the board \n", returnValue);
		_getch();
		return -1;
	}

	/* ask for timer selection */
	ReadUlong("Which timer do you want to use? (0: Timer 0, 1: Timer 1, 2: Timer 2 ) ",0,2,&readValue);
	switch ( readValue )
	{
		case 0:
			timerIndex = PCI3116_TIMER_0;
			break;
		case 1:
			timerIndex = PCI3116_TIMER_1;
			break;
		case 2:
			timerIndex = PCI3116_TIMER_2;
			break;
	}

	/* ask for timer mode */
	ReadUlong("Which timer mode do you want to use? (0: Mode 2, 1: Mode 3) ",0,1,&readValue);
	switch ( readValue )
	{
		case 0:
			timerMode = PCI3116_TIMER_MODE_2;
			break;
		case 1:
			timerMode = PCI3116_TIMER_MODE_3;
			break;
	}

	/* ask for output mode */
	ReadUlong("Which output mode do you want to use? (0: Output disabled, 1: Output enabled, 2: Inverted output) ",0,2,&readValue);
	switch ( readValue )
	{
		case 0:
			outputMode = PCI3116_OUTPUT_DISABLED;
			break;
		case 1:
			outputMode = PCI3116_OUTPUT_ENABLED;
			break;
		case 2:
			outputMode = PCI3116_OUTPUT_INVERTED;
			break;
	}
	
	/* ask for interrupts */
	ReadUlong("Do you want to enable interrupts? (0: No, 1: Yes) ",0,1,&readValue);
	enableInterrupt = (BYTE) readValue;

	/* ask for time base */
	ReadUlong("Which time base do you want to use? (0: Microseconds, 1: Milliseconds, 2: Seconds) ",0,2,&readValue);
	switch ( readValue )
	{
		case 0:
			timeBase = PCI3116_TIME_BASE_MICROSECONDS;
			break;
		case 1:
			timeBase = PCI3116_TIME_BASE_MILLISECONDS;
			break;
		case 2:
			timeBase = PCI3116_TIME_BASE_SECONDS;
			break;
	}

	/* ask for reload value */
	ReadUlong("Which reload value do you want to use? (0 to 65535) ",0,0xFFFF, &readValue);	
	reloadValue = (WORD) readValue;

	/* Enable interrupt routine */
	if ( enableInterrupt != 0 )
	{
		returnValue = i_PCI3116_SetBoardIntRoutine( boardHandle, InterruptRoutine );
		if ( returnValue != 0 )
		{
			printf("Error %d in i_PCI3116_SetBoardIntRoutine \n", returnValue);
			i_PCI3116_CloseBoard(boardHandle);
			_getch();
			return -1;
		}
	}

	/* start the counter logic */
	returnValue = i_PCI3116_InitAndStartCounterTimerWatchdog( boardHandle,
		PCI3116_TIMER_FUNCTION,	/* timer function */
		timerIndex,
		enableInterrupt,
		reloadValue,
		timeBase,
		outputMode,
		timerMode,
		0,						/* not used */
		0);						/* not used */

	/* error handling */
	if ( returnValue != 0 )
	{
		printf("error %d in i_PCI3116_InitAndStartCounterTimerWatchdog\n", returnValue);
		doContinue = 0;
	}
	else
	{
		printf("i_PCI3116_StartTimer OK \n");
		printf("Press the space key to trigger the timer \n");
		printf("\n");
	}

	/* endless loop */
	while(doContinue == 1)
	{
		BYTE timerStatus = 0;
		BYTE softwareTriggerStatus = 0;
		WORD timerValue = 0;

		/* get the timer value */
		returnValue = i_PCI3116_ReadTimerStatus( boardHandle, timerIndex, &timerStatus, &softwareTriggerStatus, &timerValue);
		if ( returnValue != 0 )
		{
			printf("Error %d in i_PCI3116_StopTimer \n", returnValue);
			doContinue = 0;
		}

		/* display value */
		printf("The timer status is %x, value is %u, software trigger is %x \r", timerStatus, timerValue, softwareTriggerStatus);

		if ( _kbhit() )
		{
			switch( _getch() )
			{
				/* space bar */
				case 32:
					returnValue = i_PCI3116_TriggerCounterTimerWatchdog(boardHandle, timerIndex);
					if ( returnValue != 0 )
					{
						printf("Error %d in i_PCI3116_TriggerTimer \n", returnValue);
						doContinue = 0;
					}
					else
					{
						printf("Timer has been triggered!                                            \n");
					}
					break;

				default:
					doContinue = 0;
					break;
			}
		}

		Sleep(100);
	}

	/* stop the counter logic */
	returnValue = i_PCI3116_StopCounterTimerWatchdog(boardHandle, timerIndex);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_StopTimer \n", returnValue);
	}
	else
	{
		printf("i_PCI3116_StopTimer OK \n");
	}

	/* reset the interrupt routine */
	if ( enableInterrupt )
	{
		returnValue = i_PCI3116_ResetBoardIntRoutine( boardHandle );
		if (returnValue != 0)
		{
			printf("Error %d in i_PCI3116_ResetBoardIntRoutine \n", returnValue);
		}
		else
		{
			printf("i_PCI3116_ResetBoardIntRoutine OK \n");
		}
	}

	/* close the board */
	returnValue = i_PCI3116_CloseBoard(boardHandle);
	if (returnValue != 0)
	{
		printf("Error %d in i_PCI3116_CloseBoard \n", returnValue);
	}
	else
	{
		printf("i_PCI3116_CloseBoard OK \n");
	}

	/* exit */
	printf("\n Press any key to exit the sample ...");
	_getch();

	return 0;
}

