/**
* This sample demonstrate how to use the trigger functionnality of the watchdog
* The sample also uses the digital outputs
**/

#include "stdafx.h"

/**
* Enables to invert a digital output status
**/
static INT ChangeOutputStatus( HANDLE boardHandle, int index )
{
	INT returnValue = 0;
	static int outputStatus[4] = {0};

	if ( outputStatus[index] == 0 )
	{
		/* set output to on */
		returnValue = i_PCI3116_Set1DigitalOutputOn( boardHandle, (BYTE) index );
		if ( returnValue != 0 )
		{
			return -1;
		}
		outputStatus[index] = 1;
	}
	else
	{
		/* set output to off */
		returnValue = i_PCI3116_Set1DigitalOutputOff( boardHandle, (BYTE) index );
		if ( returnValue != 0 )
		{
			return -1;
		}
		outputStatus[index] = 0;
	}

	/* success */
	return 0;
}

/**
* Entry point
**/
int _tmain( int /*argc*/, _TCHAR* /*argv[]*/ )
{
	INT returnValue = 0;
	HANDLE	boardHandle = NULL;
	BYTE watchdogIndex = 2;

	/* call the util method to open a board */
	returnValue = OpenBoard(&boardHandle);
	if (returnValue != 0)
	{
		printf("Error while opening the board : %d \n", (int) returnValue);
		_getch();
		return -1;
	}

	/* display usefull informations */
	printf("\n\n* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n");
	printf("Watchdog with trigger sample.\nThis sample uses a watchdog with time base in millisecond and a reload value of 5000 ms. It doesn't use interrupts.\n");
	printf("The sample also uses digital outputs to trigger the watchdog\n\n\n");
	printf("The watchdog 2 is used for digital outputs so we will use it. The watchdog 1 is used for analog outputs.\n");
	printf("* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * \n");

	/* enable digital output memory */
	returnValue = i_PCI3116_SetDigitalOutputMemoryOn(boardHandle);
	if (returnValue != 0)
	{
		printf("Error while setting digital output memory to on : %d \n", (int) returnValue);
		_getch();
		return -1;
	}

	/* start the selected component as timer */
	returnValue = i_PCI3116_InitAndStartCounterTimerWatchdog( boardHandle,
		PCI3116_WATCHDOG_FUNCTION,
		watchdogIndex,
		0,		/* interrupt disabled */
		5000,	/* reload value */
		PCI3116_TIME_BASE_MILLISECONDS,		/* time base millisecond */
		0,		/* not used */
		0,		/* not used */
		0,		/* not used */
		0 );	/* not used */

	/* endless loop */
	printf("\nWatchdog is started. Press 't' to trigger it, 0-1-2-3 to set/reset a digital output, and 'ESC' to exit this sample.\n", watchdogIndex);
	for (;;)
	{
		BYTE status = 0;
		BYTE triggerStatus = 0;
		WORD value = 0;

		/* get the timer status */
		returnValue = i_PCI3116_ReadWatchdogStatus(boardHandle,
			(BYTE)watchdogIndex,
			&status,
			&triggerStatus,
			&value);
		if ( returnValue != 0)
		{
			printf("Error while reading timer's status : %d \n", returnValue);
			/* stop the timer and exit */
			i_PCI3116_StopCounterTimerWatchdog(boardHandle, (BYTE)watchdogIndex);
			i_PCI3116_CloseBoard(boardHandle);
			_getch();
			return -1;
		}

		/* display the value */
		printf("Value : %d. Trigger : %d \t\t", (int)value, (int) triggerStatus );

		/* check if a key was hit */
		if ( _kbhit() )
		{
			int hitchar = _getch();
			switch ( hitchar )
			{
				/* t or T */
				case 116:
				case 84:
					/* trigger the timer */
					returnValue = i_PCI3116_TriggerCounterTimerWatchdog( boardHandle, (BYTE)watchdogIndex );
					if ( returnValue != 0 )
					{
						printf("Error while triggering timer : %d \n", returnValue);
						/* stop the timer and exit */
						i_PCI3116_StopCounterTimerWatchdog(boardHandle, (BYTE)watchdogIndex);
						i_PCI3116_CloseBoard(boardHandle);
						_getch();
						return -1;
					}
					break;
				/* esc */
				case 27:
					/* stop the timer */
					returnValue = i_PCI3116_StopCounterTimerWatchdog(boardHandle, (BYTE)watchdogIndex);
					if ( returnValue != 0 )
					{
						printf("Error while stopping the timer logic : %d \n", (int) returnValue);
						i_PCI3116_CloseBoard(boardHandle);
						_getch();
						return -1;
					}
					/* success */
					i_PCI3116_CloseBoard(boardHandle);
					return 0;
				/* handle the output */
				default:
					int index = -1;
					/* 0 */
					if ( hitchar == 61 || hitchar == 48 )
					{
						index = 0;
					}
					/* 1 */
					if ( hitchar == 33 || hitchar == 49 )
					{
						index = 1;
					}
					/* 2 */
					if ( hitchar == 34 || hitchar == 50 )
					{
						index = 2;
					}
					/* 3 */
					if ( hitchar == 245 || hitchar == 51 )
					{
						index = 3;
					}
					/* correct index ? */
					if ( index == -1 )
					{
						break;
					}
					/* change a digital output */
					returnValue = ChangeOutputStatus( boardHandle, index );
					if ( returnValue != 0 )
					{
						printf("Error while chaning digital output : %d \n", (int) returnValue);
						/* stop the timer and exit */
						i_PCI3116_StopCounterTimerWatchdog(boardHandle, (BYTE)watchdogIndex);
						i_PCI3116_CloseBoard(boardHandle);
						_getch();
						return -1;
					}
					break;
			}
		}
		Sleep(100);
		DisplayRunningStatus();
	}
}

