using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace WriteAnalogOutputs
{
    public partial class WriteAnalogOutputs : Form
    {
        /// <summary>
        /// Board object
        /// </summary>
        private PCI3116_NET.PCI3116 board;

        /// <summary>
        /// Useful array
        /// </summary>
        private TrackBar[] outputTrackBar;

        /// <summary>
        /// Constructor of the form
        /// </summary>
        public WriteAnalogOutputs()
        {
            InitializeComponent();

            // Create the useful array
            this.outputTrackBar = new TrackBar[4];
            this.outputTrackBar[0] = this.outputBar0;
            this.outputTrackBar[1] = this.outputBar1;
            this.outputTrackBar[2] = this.outputBar2;
            this.outputTrackBar[3] = this.outputBar3;
        }

        /// <summary>
        /// Occurs the first time the form loads
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void WriteAnalogOutputs_Load(object sender, EventArgs e)
        {
            // Construct the board object
            this.board = PCI3116_NET.PCI3116.OpenBoard(0);

            // Check the result
            if (this.board == null)
            {
                MessageBox.Show("Error while opening board 0");
                this.Close();
                return;
            }

            // Initialize the output to 0V
            for (byte i = 0; i < 4; i++)
            {
                int returnValue = 0;
                // We use bipolar mode
                // 0x7ff is 0V
                // 0x0 is -10V
                // 0xfff is 10V
                if ((returnValue = this.board.Write1AnalogOutput(i, 1, 0x7ff)) != 0)
                {
                    MessageBox.Show("Write1AnalogOutput error : " + returnValue.ToString());
                    this.Close();
                    return;
                }
            }

            // Initialize graphics
            this.InitTrackBar();
        }

        /// <summary>
        /// Initialize the track bar
        /// </summary>
        private void InitTrackBar()
        {
            for (int i = 0; i < 4; i++)
            {
                this.outputTrackBar[i].Minimum = -10;
                this.outputTrackBar[i].Maximum = 10;
                this.outputTrackBar[i].TickFrequency = 1;
                this.outputTrackBar[i].SmallChange = 1;
                this.outputTrackBar[i].LargeChange = 2;
                this.outputTrackBar[i].ValueChanged += new EventHandler(WriteAnalogOutputs_ValueChanged);
            }
        }

        /// <summary>
        /// Compute the value that must be written in the board
        /// </summary>
        /// <param name="value">The track bar value: -10 to +10</param>
        /// <returns></returns>
        private ushort ComputeOutputValue(int value)
        {
            value += 10;
            return (ushort)((value * 0xfff) / 20 );
        }

        /// <summary>
        /// Listen to the value changed event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void WriteAnalogOutputs_ValueChanged(object sender, EventArgs e)
        {
            for (byte i = 0; i < 4; i++)
            {
                if (sender == this.outputTrackBar[i])
                {
                    int returnValue = 0;
                    if ((returnValue = this.board.Write1AnalogOutput(i, 1, ComputeOutputValue(this.outputTrackBar[i].Value))) != 0)
                    {
                        MessageBox.Show("Write1AnalogOutput error : " + returnValue.ToString());
                        this.Close();
                        return;
                    }
                    return;
                }
            }
        }
    }
}